export declare enum TransferValidationStatus {
    Pending = "pending",
    Valid = "valid",
    Invalid = "invalid",
    Error = "error"
}
export interface IUpdateStatusResult {
    success: boolean;
    message?: string;
}
export declare enum UpdateStatusCode {
    Success = "success",
    NoValidator = "noValidator",
    NotPending = "notPending"
}
export interface CertificateData {
    generatorId: string;
    fromTime: string;
    toTime: string;
    metadata: any;
}
export interface EnergyTransferRequestPublicAttrs {
    id: number;
    sellerAddress: string;
    buyerAddress: string;
    transferDate: Date;
    volume: string;
    certificateData: CertificateData;
}
export declare enum State {
    Skipped = "Skipped",
    IssuanceAwaiting = "IssuanceAwaiting",
    IssuanceInProgress = "IssuanceInProgress",
    Issued = "Issued",
    PersistenceAwaiting = "PersistenceAwaiting",
    Persisted = "Persisted",
    ValidationAwaiting = "ValidationAwaiting",
    ValidationInProgress = "ValidationInProgress",
    Validated = "Validated",
    TransferAwaiting = "TransferAwaiting",
    TransferInProgress = "TransferInProgress",
    Transferred = "Transferred",
    IssuanceError = "IssuanceError",
    TransferError = "TransferError",
    ValidationError = "ValidationError",
    ValidationInvalid = "ValidationInvalid"
}
export interface EnergyTransferRequestAttrs extends EnergyTransferRequestPublicAttrs {
    createdAt: Date;
    updatedAt: Date;
    certificateId: number | null;
    state: State;
    processError: string | null;
    validationStatusRecord: Record<string, TransferValidationStatus>;
}
export interface NewAttributesParams {
    buyerAddress: string;
    sellerAddress: string;
    transferDate: Date;
    volume: string;
    certificateData: CertificateData;
}
export declare class EnergyTransferRequest {
    private attrs;
    private constructor();
    get certificateId(): number | null;
    get id(): number;
    get sites(): {
        buyerAddress: string;
        sellerAddress: string;
    };
    get volume(): string;
    issuanceStarted(): void;
    issuanceError(error: string): void;
    issuanceFinished(certificateId: number): void;
    persisted(): void;
    startValidation(validatorNames: string[]): void;
    validationError(error: string): void;
    updateValidationStatus(validatorName: string, status: TransferValidationStatus): UpdateStatusCode;
    transferStarted(): void;
    transferError(error: string): void;
    transferFinished(): void;
    toAttrs(): EnergyTransferRequestAttrs;
    toPublicAttrs(): EnergyTransferRequestPublicAttrs;
    static fromAttrs(attrs: EnergyTransferRequestAttrs): EnergyTransferRequest;
    static newAttributes(params: NewAttributesParams): Omit<EnergyTransferRequestAttrs, 'id'>;
    private nextState;
}
